==> jc-1.4.0.tar.gz: javax/rmi/CORBA/SystemException.h <==
// public class javax.rmi.CORBA.SystemException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 395f786864e7718a javax_rmi_CORBA_SystemException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_rmi_CORBA_SystemException_H_
#define _JC_javax_rmi_CORBA_SystemException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_rmi_CORBA_SystemException$sub_refs	_jc_javax_rmi_CORBA_SystemException$sub_refs;
typedef struct _jc_javax_rmi_CORBA_SystemException$sub_nonrefs	_jc_javax_rmi_CORBA_SystemException$sub_nonrefs;
typedef struct _jc_javax_rmi_CORBA_SystemException$refs	_jc_javax_rmi_CORBA_SystemException$refs;
typedef struct _jc_javax_rmi_CORBA_SystemException$nonrefs	_jc_javax_rmi_CORBA_SystemException$nonrefs;
typedef struct _jc_javax_rmi_CORBA_SystemException$object	_jc_javax_rmi_CORBA_SystemException$object;

typedef const struct _jc_javax_rmi_CORBA_SystemException$vmethods	_jc_javax_rmi_CORBA_SystemException$vmethods;
typedef const struct _jc_javax_rmi_CORBA_SystemException$vtable	_jc_javax_rmi_CORBA_SystemException$vtable;
typedef const struct _jc_javax_rmi_CORBA_SystemException$vtype	_jc_javax_rmi_CORBA_SystemException$vtype;

// Constructors
extern void _jc_javax_rmi_CORBA_SystemException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_CORBA_SystemException$object *);

// Virtual methods structure
struct _jc_javax_rmi_CORBA_SystemException$vmethods {
};

// Vtable
struct _jc_javax_rmi_CORBA_SystemException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_rmi_CORBA_SystemException$vmethods	javax_rmi_CORBA_SystemException;
};

// Vtype
struct _jc_javax_rmi_CORBA_SystemException$vtype {
	_jc_type			type;
	_jc_javax_rmi_CORBA_SystemException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_SystemException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_CORBA_SystemException$refs {
    _jc_javax_rmi_CORBA_SystemException$sub_refs	javax_rmi_CORBA_SystemException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_SystemException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_CORBA_SystemException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_rmi_CORBA_SystemException$sub_nonrefs	javax_rmi_CORBA_SystemException;
};

// Object instance structure
struct _jc_javax_rmi_CORBA_SystemException$object {
	_jc_javax_rmi_CORBA_SystemException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_CORBA_SystemException$vtype	*vtype;
	_jc_javax_rmi_CORBA_SystemException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_CORBA_SystemException$vtype _jc_javax_rmi_CORBA_SystemException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_CORBA_SystemException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_CORBA_SystemException$class_object;

#endif	/* _JC_javax_rmi_CORBA_SystemException_H_ */

==> jc-1.4.6.tar.gz: javax/rmi/CORBA/SystemException.h <==
// public class javax.rmi.CORBA.SystemException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 395f786864e7718a javax_rmi_CORBA_SystemException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_rmi_CORBA_SystemException_H_
#define _JC_javax_rmi_CORBA_SystemException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_rmi_CORBA_SystemException$sub_refs	_jc_javax_rmi_CORBA_SystemException$sub_refs;
typedef struct _jc_javax_rmi_CORBA_SystemException$sub_nonrefs	_jc_javax_rmi_CORBA_SystemException$sub_nonrefs;
typedef struct _jc_javax_rmi_CORBA_SystemException$refs	_jc_javax_rmi_CORBA_SystemException$refs;
typedef struct _jc_javax_rmi_CORBA_SystemException$nonrefs	_jc_javax_rmi_CORBA_SystemException$nonrefs;
typedef struct _jc_javax_rmi_CORBA_SystemException$object	_jc_javax_rmi_CORBA_SystemException$object;

typedef const struct _jc_javax_rmi_CORBA_SystemException$vmethods	_jc_javax_rmi_CORBA_SystemException$vmethods;
typedef const struct _jc_javax_rmi_CORBA_SystemException$vtable	_jc_javax_rmi_CORBA_SystemException$vtable;
typedef const struct _jc_javax_rmi_CORBA_SystemException$vtype	_jc_javax_rmi_CORBA_SystemException$vtype;

// Constructors
extern void _jc_javax_rmi_CORBA_SystemException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_CORBA_SystemException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_rmi_CORBA_SystemException$vmethods {
};

// Vtable
struct _jc_javax_rmi_CORBA_SystemException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_rmi_CORBA_SystemException$vmethods	javax_rmi_CORBA_SystemException;
};

// Vtype
struct _jc_javax_rmi_CORBA_SystemException$vtype {
	_jc_type			type;
	_jc_javax_rmi_CORBA_SystemException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_SystemException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_CORBA_SystemException$refs {
    _jc_javax_rmi_CORBA_SystemException$sub_refs	javax_rmi_CORBA_SystemException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_SystemException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_CORBA_SystemException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_rmi_CORBA_SystemException$sub_nonrefs	javax_rmi_CORBA_SystemException;
};

// Object instance structure
struct _jc_javax_rmi_CORBA_SystemException$object {
	_jc_javax_rmi_CORBA_SystemException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_CORBA_SystemException$vtype	*vtype;
	_jc_javax_rmi_CORBA_SystemException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_CORBA_SystemException$vtype _jc_javax_rmi_CORBA_SystemException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_CORBA_SystemException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_CORBA_SystemException$class_object;

#endif	/* _JC_javax_rmi_CORBA_SystemException_H_ */
